@@ -19,6 +19,12 @@
 ;;; example:
 ;;; /eval (ping 'buddy 10)
 
+(define (times buddy count message)
+  "send MESSAGE to BUDDY, COUNT times"
+  (fh-send-message buddy message)
+  (if (= count 1)
+      '()
+      (times buddy (- count 1) message)))
 
 (define (ping buddy count)
   "send ping messages to buddy"
@@ -63,3 +69,18 @@
       (begin
 	(display "/buzz: wrong number of arguments\n")
 	(display "usage: /buzz buddy\n"))))
+
+;;; Dynamic command support
+(fh-register-command!
+ '("/times"
+   "/times BUDDY COUNT MESSAGE\n\t- send MESSAGE to BUDDY, COUNT times"))
+
+(define (/times args-list)
+  (set! args-list (list->strlist args-list))
+  (if (= (length args-list) 3)
+      (times (list-ref args-list 0) 
+	     (string->number (list-ref args-list 1))
+	     (list-ref args-list 2))
+      (begin
+	(display "/times: wrong number of arguments\n")
+	(display "usage: send BUDDY COUNT MESSAGE\n"))))
