@@ -209,7 +209,7 @@ get_token_with_strdelim_i (char **line, char *delim)
 }
 
 char *
-parse_color_code (char *string)
+parse_color_code (const char *string)
 {
   char *parsedstring;
   int i, j;
@@ -240,7 +240,7 @@ parse_color_code (char *string)
 }
 
 char *
-parse_font_tag (char *string)
+parse_font_tag (const char *string)
 {
   char *parsedstring;
   int i, j;
@@ -274,7 +274,7 @@ parse_font_tag (char *string)
 }
 
 char *
-parse_control_characters (char *string)
+parse_control_characters (const char *string)
 {
   char *parsedstring;
   int i, j;
@@ -294,8 +294,8 @@ parse_control_characters (char *string)
 
 }
 
-char *
-filter_message (char *message)
+const char *
+filter_message (const char *message)
 {
   char *color_parsedstring = NULL;
   char *font_parsedstring = NULL;
