@@ -71,10 +71,10 @@ char *stripwhite (char *string);
 char *get_token (char **line);
 char *get_token_with_strdelim (char **line, char *delim);
 char *get_token_with_strdelim_i (char **line, char *delim);
-char *parse_color_code (char *string);
-char *parse_font_tag (char *string);
-char *parse_control_characters (char *string);
-char *filter_message (char *message);
+char *parse_color_code (const char *string);
+char *parse_font_tag (const char *string);
+char *parse_control_characters (const char *string);
+const char *filter_message (const char *message);
 char *old_filter_message (char *message);
 char *get_utc_time (char *time_secs);
 char *get_home_directory (void);
