@@ -178,7 +178,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
 static struct argp argp = { options, parse_opt, args_doc, doc };
   
 
-void
+static void
 running_for_first_time (void)
 {
   struct stat *config_file_stat = NULL;
@@ -203,7 +203,7 @@ running_for_first_time (void)
   if (stat (config_filename, config_file_stat) != 0)
     {
       // config file missing, so touch it
-      config_file_fd = open (config_filename, O_CREAT | O_RDWR);
+      config_file_fd = open (config_filename, O_CREAT | O_RDWR, S_IRWXU);
       if (config_file_fd == -1)
 	{
 	  perror ("open[config_file]");
@@ -249,8 +249,8 @@ running_for_first_time (void)
 }
 
 
-void
-inner_main (int argc, char **argv)
+static void
+inner_main (void *closure, int argc, char **argv)
 {
   /* your guile environment is ready :)
      you are free to eval any guile code */
