@@ -30,7 +30,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <yahoo2.h>
+#include <libyahoo2/yahoo2.h>
 #include <regex.h>
 
 #include "freehoo.h"
