@@ -59,7 +59,7 @@ set_auto_insert_mode (int auto_insert_mode_value)
 }
 
 void 
-set_current_target_buddy (char *current_target_buddy_value, current_target_buddy_mode_t current_target_buddy_mode_value)
+set_current_target_buddy (const char *current_target_buddy_value, current_target_buddy_mode_t current_target_buddy_mode_value)
 {
   if (current_target_buddy_value)
     strcpy (current_target_buddy, current_target_buddy_value);
@@ -91,7 +91,7 @@ send_message (char *to, char *message)
   if (get_hook_return () == 1)
     return;
 
-  yahoo_send_im (get_fh_session ()->id, NULL, to, message, 0);
+  yahoo_send_im (get_fh_session ()->id, NULL, to, message, 0, 0);
 }
 
 /* this function is primarily for scm-procedure. using this function
@@ -104,7 +104,7 @@ send_message_no_hook (char *to, char *message)
   // it will confuse "session (AUTU-INSERT-MODE). 
   // set_current_target_buddy (to); // AUTO-INSERT-MODE
 
-  yahoo_send_im (get_fh_session ()->id, NULL, to, message, 0);
+  yahoo_send_im (get_fh_session ()->id, NULL, to, message, 0, 0);
 }
 
 void 
