@@ -121,7 +121,7 @@ yahoo_status_code (enum yahoo_status s)
 }
 
 int
-ext_yahoo_log (char *fmt, ...)
+ext_yahoo_log (const char *fmt, ...)
 {
 // Not implemented right now
 //   va_list ap;
@@ -292,8 +292,8 @@ yahoo_webcam_timeout_callback (int id)
   return 1;
 }
 
-static char *
-get_buddy_name (char *yid)
+static const char *
+get_buddy_name (const char *yid)
 {
   YList *b;
   for (b = buddies; b; b = b->next)
@@ -323,7 +323,7 @@ find_conf_room_by_name_and_id (int id, const char *name)
 }
 
 void
-ext_yahoo_got_conf_invite (int id, char *who, char *room, char *msg,
+ext_yahoo_got_conf_invite (int id, const char *me, const char *who, const char *room, const char *msg,
 			   YList * members)
 {
   conf_room *cr = y_new0 (conf_room, 1);
@@ -342,7 +342,7 @@ ext_yahoo_got_conf_invite (int id, char *who, char *room, char *msg,
 }
 
 void
-ext_yahoo_conf_userdecline (int id, char *who, char *room, char *msg)
+ext_yahoo_conf_userdecline (int id, const char *me, const char *who, const char *room, const char *msg)
 {
   YList *l;
   conf_room *cr = find_conf_room_by_name_and_id (id, room);
@@ -365,7 +365,7 @@ ext_yahoo_conf_userdecline (int id, char *who, char *room, char *msg)
 }
 
 void
-ext_yahoo_conf_userjoin (int id, char *who, char *room)
+ext_yahoo_conf_userjoin (int id, const char *me, const char *who, const char *room)
 {
   conf_room *cr = find_conf_room_by_name_and_id (id, room);
   if (cr)
@@ -385,7 +385,7 @@ ext_yahoo_conf_userjoin (int id, char *who, char *room)
 }
 
 void
-ext_yahoo_conf_userleave (int id, char *who, char *room)
+ext_yahoo_conf_userleave (int id, const char *me, const char *who, const char *room)
 {
   YList *l;
   conf_room *cr = find_conf_room_by_name_and_id (id, room);
@@ -407,9 +407,9 @@ ext_yahoo_conf_userleave (int id, char *who, char *room)
 }
 
 void
-ext_yahoo_conf_message (int id, char *who, char *room, char *msg, int utf8)
+ext_yahoo_conf_message (int id, const char *me, const char *who, const char *room, const char *msg, int utf8)
 {
-  char *umsg = msg;
+  char *umsg = (char *) msg;
   char buffer[4096];
 
   if (utf8)
@@ -418,7 +418,7 @@ ext_yahoo_conf_message (int id, char *who, char *room, char *msg, int utf8)
   who = get_buddy_name (who);
   sprintf (buffer, "[%s] %s", room, msg);
 
-  ext_yahoo_got_im (id, who, buffer, 0, 0, utf8);
+  ext_yahoo_got_im (id, me, who, buffer, 0, 0, utf8);
 
   // AUTO-INSERT-MODE
   set_current_target_buddy (room,current_target_buddy_mode_receive);
@@ -453,13 +453,13 @@ print_chat_member (struct yahoo_chat_member *ycm)
 }
 
 void
-ext_yahoo_chat_cat_xml (int id, char *xml)
+ext_yahoo_chat_cat_xml (int id, const char *xml)
 {
   PRINTF_MESSAGE ("%s\n", xml);
 }
 
 void
-ext_yahoo_chat_join (int id, char *room, char *topic, YList * members, int fd)
+ext_yahoo_chat_join (int id, const char *me, const char *room, const char *topic, YList * members, int fd)
 {
   PRINTF_MESSAGE ("You have joined the chatroom %s with topic %s\n",
 		  room, topic);
@@ -481,7 +481,7 @@ ext_yahoo_chat_join (int id, char *room, char *topic, YList * members, int fd)
 }
 
 void
-ext_yahoo_chat_userjoin (int id, char *room, struct yahoo_chat_member *who)
+ext_yahoo_chat_userjoin (int id, const char *me, const char *room, struct yahoo_chat_member *who)
 {
   print_chat_member (who);
   PRINTF_MESSAGE (" joined the chatroom %s\n", room);
@@ -492,16 +492,16 @@ ext_yahoo_chat_userjoin (int id, char *room, struct yahoo_chat_member *who)
 }
 
 void
-ext_yahoo_chat_userleave (int id, char *room, char *who)
+ext_yahoo_chat_userleave (int id, const char *me, const char *room, const char *who)
 {
   PRINTF_MESSAGE ("%s left the chatroom %s\n", who, room);
 }
 
 void
-ext_yahoo_chat_message (int id, char *who, char *room, char *msg,
+ext_yahoo_chat_message (int id, const char *me, const char *who, const char *room, const char *msg,
 			int msgtype, int utf8)
 {
-  char *umsg = msg;
+  char *umsg = (char *)msg;
   char *charpos;
 
   if (utf8)
@@ -531,8 +531,8 @@ ext_yahoo_chat_message (int id, char *who, char *room, char *msg,
 }
 
 void
-ext_yahoo_status_changed (int id, char *who, int stat, char *msg,
-			  int away)
+ext_yahoo_status_changed (int id, const char *who, int stat, const char *msg,
+			  int away, int idle, int mobile)
 {
   yahoo_account *ya = NULL;
   YList *b;
@@ -619,9 +619,9 @@ ext_yahoo_got_ignore (int id, YList * igns)
 }
 
 void
-ext_yahoo_got_im (int id, char *who, char *msg, long tm, int stat, int utf8)
+ext_yahoo_got_im (int id, const char *me, const char *who, const char *msg, long tm, int stat, int utf8)
 {
-  char *umsg = msg;
+  char *umsg = (char *)msg;
 
   if (stat == 2)
     {
@@ -670,7 +670,7 @@ ext_yahoo_got_im (int id, char *who, char *msg, long tm, int stat, int utf8)
 }
 
 void
-ext_yahoo_rejected (int id, char *who, char *msg)
+ext_yahoo_rejected (int id, const char *who, const char *msg)
 {
   PRINTF_MESSAGE ("%s has rejected you%s%s\n", who,
 		  (msg ? " with the message:\n" : "."),
@@ -678,7 +678,7 @@ ext_yahoo_rejected (int id, char *who, char *msg)
 }
 
 void
-ext_yahoo_contact_added (int id, char *myid, char *who, char *msg)
+ext_yahoo_contact_added (int id, const char *myid, const char *who, const char *msg)
 {
   char buf[1024];
 
@@ -705,7 +705,7 @@ ext_yahoo_contact_added (int id, char *myid, char *who, char *msg)
 }
 
 void
-ext_yahoo_typing_notify (int id, char *who, int stat)
+ext_yahoo_typing_notify (int id, const char *me, const char *who, int stat)
 {
   /* Disable it for now....
      if (stat && do_typing_notify)
@@ -716,7 +716,7 @@ ext_yahoo_typing_notify (int id, char *who, int stat)
 }
 
 void
-ext_yahoo_game_notify (int id, char *who, int stat)
+ext_yahoo_game_notify (int id, const char *me, const char *who, int stat)
 {
   if (stat)
     {
@@ -729,7 +729,7 @@ ext_yahoo_game_notify (int id, char *who, int stat)
 }
 
 void
-ext_yahoo_mail_notify (int id, char *from, char *subj, int cnt)
+ext_yahoo_mail_notify (int id, const char *from, const char *subj, int cnt)
 {
   char buff[1024] = { 0 };
 
@@ -809,7 +809,7 @@ ext_yahoo_got_webcam_image (int id, const char *who,
 }
 
 void
-ext_yahoo_webcam_viewer (int id, char *who, int connect)
+ext_yahoo_webcam_viewer (int id, const char *who, int connect)
 {
   switch (connect)
     {
@@ -827,7 +827,7 @@ ext_yahoo_webcam_viewer (int id, char *who, int connect)
 }
 
 void
-ext_yahoo_webcam_closed (int id, char *who, int reason)
+ext_yahoo_webcam_closed (int id, const char *who, int reason)
 {
   switch (reason)
     {
@@ -865,13 +865,13 @@ ext_yahoo_webcam_data_request (int id, int send)
 }
 
 void
-ext_yahoo_webcam_invite (int id, char *from)
+ext_yahoo_webcam_invite (int id, const char *me, const char *from)
 {
   PRINTF_MESSAGE ("Got a webcam invitation from %s\n", from);
 }
 
 void
-ext_yahoo_webcam_invite_reply (int id, char *from, int accept)
+ext_yahoo_webcam_invite_reply (int id, const char *me, const char *from, int accept)
 {
   if (accept)
     {
@@ -884,7 +884,7 @@ ext_yahoo_webcam_invite_reply (int id, char *from, int accept)
 }
 
 void
-ext_yahoo_system_message (int id, char *msg)
+ext_yahoo_system_message (int id, const char *msg)
 {
   if (ignore_system)
     return;
@@ -962,7 +962,7 @@ ext_yahoo_got_cookies (int id)
 }
 
 void
-ext_yahoo_login_response (int id, int succ, char *url)
+ext_yahoo_login_response (int id, int succ, const char *url)
 {
   char buff[1024];
 
@@ -1020,7 +1020,7 @@ ext_yahoo_login_response (int id, int succ, char *url)
 }
 
 void
-ext_yahoo_error (int id, char *err, int fatal)
+ext_yahoo_error (int id, const char *err, int fatal, int num)
 {
   PRINTF_MESSAGE ("Yahoo Error: %s\n", err);
   /*
@@ -1073,7 +1073,7 @@ yahoo_set_current_state (int yahoo_state)
 }
 
 int
-ext_yahoo_connect (char *host, int port)
+ext_yahoo_connect (const char *host, int port)
 {
   struct sockaddr_in serv_addr;
   static struct hostent *server;
@@ -1221,7 +1221,7 @@ yahoo_callback (struct _conn *c, yahoo_input_condition cond)
 }
 
 int
-ext_yahoo_connect_async (int id, char *host, int port,
+ext_yahoo_connect_async (int id, const char *host, int port,
 			 yahoo_connect_callback callback, void *data)
 {
   struct sockaddr_in serv_addr;
@@ -1276,6 +1276,31 @@ ext_yahoo_connect_async (int id, char *host, int port,
     }
 }
 
+void ext_yahoo_got_buddyicon_checksum(int id, const char *a, const char *b, int checksum)
+{
+	LOG(("got buddy icon checksum"));
+}
+
+void ext_yahoo_got_buddyicon(int id, const char *a, const char *b, const char *c, int checksum)
+{
+	LOG(("got buddy icon"));
+}
+
+void ext_yahoo_buddyicon_uploaded(int id, const char *url)
+{
+	LOG(("buddy icon uploaded"));
+}
+
+void ext_yahoo_got_buddyicon_request(int id, const char *me, const char *who)
+{
+	LOG(("got buddy icon request from %s",who));
+}
+
+void ext_yahoo_got_ping(int id, const char *errormsg)
+{ 
+ 	LOG(("got ping errormsg %s", errormsg));
+}
+
 /*
  * Callback handling code ends here
  ***********************************/
@@ -1380,8 +1405,8 @@ void get_file_geturl_callback(int id, int fd, int error, const char * _fname, un
 }
 
 void
-ext_yahoo_got_file (int id, char *who, char *url, long expires, char *msg,
-		    char *fname, unsigned long fesize)
+ext_yahoo_got_file (int id, const char *me, const char *who, const char *url, long expires, const char *msg,
+		    const char *fname, unsigned long fesize)
 {
   get_file_geturl_data_t data;
 
@@ -1394,11 +1419,11 @@ ext_yahoo_got_file (int id, char *who, char *url, long expires, char *msg,
       PRINTF_MESSAGE ("[%s] has sent a file [%s] (%lu bytes)\n", who, fname,fesize);
     }
 
-    data.who = who;
-    data.url = url;
-    data.fname = fname;
+    data.who = (char *)who;
+    data.url = (char *)url;
+    data.fname = (char *)fname;
     data.fsize = fesize;
-    data.msg = msg;
+    data.msg = (char *)msg;
     yahoo_get_url_handle(id,url,get_file_geturl_callback,&data);
 }
 
@@ -1407,13 +1432,13 @@ ext_yahoo_got_identities (int id, YList * ids)
 {
 }
 void
-ext_yahoo_chat_yahoologout (int id)
+ext_yahoo_chat_yahoologout (int id, const char *me)
 {
   LOG (("got chat logout"));
 }
 
 void
-ext_yahoo_chat_yahooerror (int id)
+ext_yahoo_chat_yahooerror (int id, const char *me)
 {
   LOG (("got chat logout"));
 }
@@ -1470,6 +1495,11 @@ register_callbacks ()
   yc.ext_yahoo_remove_handler = ext_yahoo_remove_handler;
   yc.ext_yahoo_connect = ext_yahoo_connect;
   yc.ext_yahoo_connect_async = ext_yahoo_connect_async;
+  yc.ext_yahoo_got_buddyicon = ext_yahoo_got_buddyicon;
+  yc.ext_yahoo_got_buddyicon_checksum = ext_yahoo_got_buddyicon_checksum;
+  yc.ext_yahoo_buddyicon_uploaded = ext_yahoo_buddyicon_uploaded;
+  yc.ext_yahoo_got_buddyicon_request = ext_yahoo_got_buddyicon_request;
+  yc.ext_yahoo_got_ping = ext_yahoo_got_ping;
 
   yahoo_register_callbacks (&yc);
 
